@@ -4,6 +4,7 @@
 from ._plot_object import PlotObject
 from ._plot import Plot
 from ._line import Line
+from ._scatter import Scatter
 from ._sub_plots import SubPlots
 
-__all__ = ["Line", "Plot", "PlotObject", "SubPlots"]
+__all__ = ["Line", "Plot", "PlotObject", "SubPlots", "Scatter"]
